(function ($) {

  Drupal.behaviors.quickpost_bookmarklet = {
    attach: function (context, settings) {
      // Get references to the form and elements
      var settings_form = $('.quickpost_bookmarklet_settings_form', context);
      var content_type_element = settings_form.find(':input[name=content_type]');
      var title_element = settings_form.find(':input[name=title_template]');
      var body_element = settings_form.find(':input[name=body_template]');
      
      // Add click event to the Generate Bookmarklet button
      settings_form.find('#edit-generate-bookmarklet').click(function(e) {
        e.preventDefault();
        
        // Remove the old bookmarklet, if they have already generated one
        settings_form.find('.bookmarklet_container').empty();
        
        // Get the template
        var title_template = title_element.val();
        var body_template = body_element.val();
        
        // Replace the tokens
        title_template = quickpost_bookmarklet_replace_tokens(title_template);
        body_template = quickpost_bookmarklet_replace_tokens(body_template);
              
        // Build the JS that will be used for the bookmarklet
        var js = "var nodeaddpath='" + Drupal.settings.bookmarklet_base_path + "/" + content_type_element.val() + "', d=document, w=window, e=w.getSelection, k=d.getSelection, x=d.selection, s=(e?e():(k)?k():(x?x.createRange().text:0)), \
          l=d.location, e=encodeURIComponent, \
          title='" + title_template + "',\
          body='" + body_template + "',\
          url = nodeaddpath + '?edit[title]=' + e(title) + '&edit[body][und][0][value]=' + e(body); \
          a = function(){if(!w.open(url,'quickpost','toolbar=0,resizable=1,scrollbars=1,status=1,width=1024,height=570')) l.href=url;};if (/Firefox/.test(navigator.userAgent)) setTimeout(a, 0); else a(); void(0)";
        
        // Build options for the minifier
        var options = {
          output_format: 'text',
          output_info: 'compiled_code',
          js_code: js
        };
        
        // Use the Google Closure Compiler to minify the JS
        $.post("http://closure-compiler.appspot.com/compile", options, function(data) {
          // Create the bookmarklet and explanation, and append to the page
          var bookmarklet = $('<a>Bookmarklet</a>').attr('href', 'javascript:' + data);
          var explanation = $('<div>Drag the link above into your bookmark toolbar</div>');
          settings_form.find('.bookmarklet_container').append(bookmarklet).append(explanation);
        });           
      });
    }
  };
  
  // Function to replace 
  quickpost_bookmarklet_replace_tokens = function(str) {
    return str.replace(/'/g, '"')
      .replace(/\[title\]/gi, "' + d.title + '")
      .replace(/\[url\]/gi, "' + d.location + '")
      .replace(/\[selection\]/gi, "' + s + '")
      .replace(/\n/g, "\\n");
  }
  
}(jQuery));


